@@ -48,6 +48,8 @@ def read(file_list, workers=1):
     # derive number of frames to prepare for
     total_num_frames = 0
     for i in range(0, len(data)):
+        if (data[i][2] is True):
+            continue
         total_num_frames += data[i][0].shape[2]
 
     # pre-allocate array sizes
@@ -204,5 +206,11 @@ def __themis_readfile_worker(file):
     # close gzip file
     unzipped.close()
 
+    # check to see if the image is empty
+    if (images.size == 0):
+        print("Error reading image file: found no image data")
+        problematic = True
+        error_message = "no image data"
+
     # return
     return images, metadata_dict_list, problematic, file, error_message
